==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfUsedFont.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfUsedFont(SpireObject):
    """
    Represents the used fonts in a PDF document.
    """

    @property
    def Name(self) -> str:
        """
        Gets the name.
        """
        GetDllLibPdf().PdfUsedFont_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Name.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfUsedFont_get_Name(self.Ptr))
        return ret

    @property
    def Size(self) -> float:
        """
        Gets the size.
        """
        GetDllLibPdf().PdfUsedFont_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Size.restype = c_float
        ret = GetDllLibPdf().PdfUsedFont_get_Size(self.Ptr)
        return ret

    @property
    def Style(self) -> 'PdfFontStyle':
        """
        Gets the style.
        """
        GetDllLibPdf().PdfUsedFont_get_Style.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Style.restype = c_int
        ret = GetDllLibPdf().PdfUsedFont_get_Style(self.Ptr)
        objwrapped = PdfFontStyle(ret)
        return objwrapped

    @property
    def Type(self) -> 'PdfFontType':
        """
        Gets the type.
        """
        GetDllLibPdf().PdfUsedFont_get_Type.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Type.restype = c_int
        ret = GetDllLibPdf().PdfUsedFont_get_Type(self.Ptr)
        objwrapped = PdfFontType(ret)
        return objwrapped

    def Replace(self, fontToReplace: 'PdfFontBase'):
        """
        Replaces the specified new font.
        """
        intPtrfontToReplace: c_void_p = fontToReplace.Ptr
        GetDllLibPdf().PdfUsedFont_Replace.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfUsedFont_Replace(self.Ptr, intPtrfontToReplace)

    @staticmethod
    def ScaleFontSize(page: 'PdfPageBase', fontNames: List[str], factor: float):
        """
        Scale the font size specified page.
        """
        intPtrpage: c_void_p = page.Ptr
        countfontNames = len(fontNames)
        ArrayTypefontNames = c_wchar_p * countfontNames
        arrayfontNames = ArrayTypefontNames()
        for i in range(0, countfontNames):
            arrayfontNames[i] = fontNames[i]
        GetDllLibPdf().PdfUsedFont_ScaleFontSize.argtypes = [c_void_p, c_void_p, ArrayTypefontNames, c_int, c_float]
        GetDllLibPdf().PdfUsedFont_ScaleFontSize(None, intPtrpage, arrayfontNames, countfontNames, factor)

    def Dispose(self):
        """
        Dispose font
        """
        GetDllLibPdf().PdfUsedFont_Dispose.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_Dispose(self.Ptr)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfUsedFont.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfUsedFont(SpireObject):
    """
    Represents the used fonts in a PDF document.
    """

    @property
    def Name(self) -> str:
        """
        Gets the name.
        """
        GetDllLibPdf().PdfUsedFont_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Name.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfUsedFont_get_Name,self.Ptr))
        return ret

    @property
    def Size(self) -> float:
        """
        Gets the size.
        """
        GetDllLibPdf().PdfUsedFont_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Size.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfUsedFont_get_Size,self.Ptr)
        return ret

    @property
    def Style(self) -> 'PdfFontStyle':
        """
        Gets the style.
        """
        GetDllLibPdf().PdfUsedFont_get_Style.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Style.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfUsedFont_get_Style,self.Ptr)
        objwrapped = PdfFontStyle(ret)
        return objwrapped

    @property
    def Type(self) -> 'PdfFontType':
        """
        Gets the type.
        """
        GetDllLibPdf().PdfUsedFont_get_Type.argtypes = [c_void_p]
        GetDllLibPdf().PdfUsedFont_get_Type.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfUsedFont_get_Type,self.Ptr)
        objwrapped = PdfFontType(ret)
        return objwrapped

    def Replace(self, fontToReplace: 'PdfFontBase'):
        """
        Replaces the specified new font.
        """
        intPtrfontToReplace: c_void_p = fontToReplace.Ptr
        GetDllLibPdf().PdfUsedFont_Replace.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfUsedFont_Replace,self.Ptr, intPtrfontToReplace)

    @staticmethod
    def ScaleFontSize(page: 'PdfPageBase', fontNames: List[str], factor: float):
        """
        Scale the font size specified page.
        """
        intPtrpage: c_void_p = page.Ptr
        countfontNames = len(fontNames)
        ArrayTypefontNames = c_wchar_p * countfontNames
        arrayfontNames = ArrayTypefontNames()
        for i in range(0, countfontNames):
            arrayfontNames[i] = fontNames[i]
        GetDllLibPdf().PdfUsedFont_ScaleFontSize.argtypes = [c_void_p, c_void_p, ArrayTypefontNames, c_int, c_float]
        CallCFunction(GetDllLibPdf().PdfUsedFont_ScaleFontSize,None, intPtrpage, arrayfontNames, countfontNames, factor)

    def Dispose(self):
        """
        Dispose font
        """
        GetDllLibPdf().PdfUsedFont_Dispose.argtypes = [c_void_p]
        CallCFunction(GetDllLibPdf().PdfUsedFont_Dispose,self.Ptr)
